Data Pipeline as Transports
-----------------------------------------

This is a library which contains different transports as data pipelines.




Run files
-------------------------------------------------

.. code-block::
    poetry run python ./main


